#!/usr/bin/env python

# Copyright (c) me.
# Distributed under the terms of the Modified BSD License.

"""
Information about the frontend package of the widgets.
"""

module_name = "myproject"
module_version = "^0.1.0"
