if [ -z ${CONDA_BUILD+x} ]; then
    source /Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/work/build_env_setup.sh
fi
/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin/python -m pip install --no-deps --no-build-isolation . -vv