export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
export ARCH="arm64"
export PREFIX="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
export BUILD_PREFIX="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_build_env"
export SYS_PREFIX="/Users/builder/cbouss/miniconda3/envs/buildout"
export SYS_PYTHON="/Users/builder/cbouss/miniconda3/envs/buildout/bin/python"
export SUBDIR="osx-arm64"
export build_platform="osx-arm64"
export SRC_DIR="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/work"
export ROOT="/Users/builder/cbouss/miniconda3/envs/buildout"
export CONDA_PY="312"
export PY3K="1"
export PY_VER="3.12"
export STDLIB_DIR="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/python3.12"
export SP_DIR="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/python3.12/site-packages"
export PYTHON="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin/python"
export NPY_VER="1.26"
export CONDA_NPY="126"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.34"
export CONDA_PERL="5.34"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3.5"
export CONDA_R="3.5"
export PKG_NAME="hatch-jupyter-builder"
export PKG_VERSION="0.8.3"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/Users/builder/cbouss/perseverance-python-buildout/aggregate/hatch-jupyter-builder-feedstock/recipe"
export CPU_COUNT="8"
export LANG="en_CA.UTF-8"
export SHLIB_EXT=".dylib"
export PATH="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_build_env/bin:/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin:/Users/builder/cbouss/miniconda3/envs/buildout/bin:/Users/builder/cbouss/miniconda3/condabin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin:/Applications/VMware Fusion Tech Preview.app/Contents/Public:/Library/Apple/usr/bin"
export HOME="/Users/builder"
export PKG_CONFIG_PATH="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export OSX_ARCH="arm64"
export MACOSX_DEPLOYMENT_TARGET="11.1"
export BUILD="arm64-apple-darwin20.0.0"
export extend_keys="{'ignore_version', 'pin_run_as_build', 'ignore_build_only_deps', 'extend_keys'}"
export zip_keys="[['python', 'numpy']]"
export pin_run_as_build="OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('libboost', {'max_pin': 'x.x.x'})])"
export ignore_build_only_deps="{'numpy', 'python'}"
export boost_cpp="1.82"
export c_compiler="clang"
export mpfr="4"
export libffi="3.4"
export xz="5"
export pixman="0.40"
export expat="2"
export VERBOSE_AT="V=1"
export proj4="5.2.0"
export target_platform="osx-arm64"
export openssl="3.0"
export libnetcdf="4.8"
export cpu_optimization_target="nocona"
export freetype="2.10"
export gnu="2.12.2"
export gstreamer="1.14"
export python_impl="cpython"
export libxml2="2.10"
export macos_machine="arm64-apple-darwin20.0.0"
export libgd="2.3.3"
export CONDA_BUILD_SYSROOT="/Library/Developer/CommandLineTools/SDKs/MacOSX11.1.sdk"
export fortran_compiler="gfortran"
export fortran_compiler_version="11.2.0"
export harfbuzz="4.3.0"
export VERBOSE_CM="VERBOSE=1"
export dbus="1"
export apr="1.7.0"
export boost="1.82"
export g2clib="1.6"
export serf="1.3.9"
export llvm_variant="llvm"
export rust_compiler_version="1.71.1"
export c_compiler_version="14"
export hdf4="4.2"
export libtiff="4.2"
export openblas="0.3.21"
export hdfeos5="5.1"
export icu="73"
export zstd="1.5.2"
export python_implementation="cpython"
export zlib="1.2"
export libkml="1.3"
export glib="2"
export r_implementation="r-base"
export rust_compiler="rust"
export channel_targets="defaults"
export r_base="3.5"
export cxx_compiler="clangxx"
export clang_variant="clang"
export r_version="3.5.0"
export openjpeg="2.3"
export libprotobuf="3.20.3"
export sqlite="3"
export mkl="2023.*"
export libpng="1.6"
export giflib="5"
export cxx_compiler_version="14"
export libgsasl="1.10"
export cairo="1.16"
export blas_impl="openblas"
export libwebp="1.3.2"
export bzip2="1.0"
export libdap4="3.19"
export hdf5="1.12.1"
export jpeg="9"
export gmp="6.2"
export macos_min_version="11.1"
export libxslt="1.1"
export fontconfig="2.14"
export boostsrap="yes"
export hdfeos2="2.20"
export lzo="2"
export cyrus_sasl="2.1.28"
export gst_plugins_base="1.14"
export readline="8.1"
export cran_mirror="https://mran.microsoft.com/snapshot/2018-01-01"
export libgdal="3.0"
export geos="3.9.1"
export proj="7.2.0"
export tk="8.6"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/Users/builder/cbouss/miniconda3/envs/buildout/bin/python' -m conda shell.bash hook)"
conda activate "/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
conda activate --stack "/Users/builder/cbouss/perseverance-python-buildout/croot/hatch-jupyter-builder_1701803326478/_build_env"
